@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,23 +13,21 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
-from typing import Callable, Dict, Optional, Sequence, Tuple
+from typing import Callable, Dict, Optional, Sequence, Tuple, Union
 
 from google.api_core import grpc_helpers  # type: ignore
 from google.api_core import operations_v1  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+import google.auth  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.cloud.documentai_v1beta2.types import document
 from google.cloud.documentai_v1beta2.types import document_understanding
-from google.longrunning import operations_pb2 as operations  # type: ignore
-
+from google.longrunning import operations_pb2  # type: ignore
 from .base import DocumentUnderstandingServiceTransport, DEFAULT_CLIENT_INFO
 
 
@@ -55,7 +52,7 @@ class DocumentUnderstandingServiceGrpcTransport(DocumentUnderstandingServiceTran
         self,
         *,
         host: str = "us-documentai.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         channel: grpc.Channel = None,
@@ -69,7 +66,8 @@ class DocumentUnderstandingServiceGrpcTransport(DocumentUnderstandingServiceTran
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -180,7 +178,7 @@ class DocumentUnderstandingServiceGrpcTransport(DocumentUnderstandingServiceTran
     def create_channel(
         cls,
         host: str = "us-documentai.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -211,13 +209,15 @@ class DocumentUnderstandingServiceGrpcTransport(DocumentUnderstandingServiceTran
             google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
               and ``credentials_file`` are passed.
         """
-        scopes = scopes or cls.AUTH_SCOPES
+
+        self_signed_jwt_kwargs = cls._get_self_signed_jwt_kwargs(host, scopes)
+
         return grpc_helpers.create_channel(
             host,
             credentials=credentials,
             credentials_file=credentials_file,
-            scopes=scopes,
             quota_project_id=quota_project_id,
+            **self_signed_jwt_kwargs,
             **kwargs,
         )
 
@@ -245,7 +245,7 @@ class DocumentUnderstandingServiceGrpcTransport(DocumentUnderstandingServiceTran
     def batch_process_documents(
         self,
     ) -> Callable[
-        [document_understanding.BatchProcessDocumentsRequest], operations.Operation
+        [document_understanding.BatchProcessDocumentsRequest], operations_pb2.Operation
     ]:
         r"""Return a callable for the batch process documents method over gRPC.
 
@@ -266,7 +266,7 @@ class DocumentUnderstandingServiceGrpcTransport(DocumentUnderstandingServiceTran
             self._stubs["batch_process_documents"] = self.grpc_channel.unary_unary(
                 "/google.cloud.documentai.v1beta2.DocumentUnderstandingService/BatchProcessDocuments",
                 request_serializer=document_understanding.BatchProcessDocumentsRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["batch_process_documents"]
 
