@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -36,7 +34,6 @@ from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.documentai_v1beta3.types import document
 from google.cloud.documentai_v1beta3.types import document_processor_service
-
 from .transports.base import DocumentProcessorServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import DocumentProcessorServiceGrpcTransport
 from .transports.grpc_asyncio import DocumentProcessorServiceGrpcAsyncIOTransport
@@ -59,7 +56,7 @@ class DocumentProcessorServiceClientMeta(type):
     def get_transport_class(
         cls, label: str = None,
     ) -> Type[DocumentProcessorServiceTransport]:
-        """Return an appropriate transport class.
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -87,7 +84,8 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -114,14 +112,15 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
 
         return api_endpoint.replace(".googleapis.com", ".mtls.googleapis.com")
 
-    DEFAULT_ENDPOINT = "us-documentai.googleapis.com"
+    DEFAULT_ENDPOINT = "documentai.googleapis.com"
     DEFAULT_MTLS_ENDPOINT = _get_default_mtls_endpoint.__func__(  # type: ignore
         DEFAULT_ENDPOINT
     )
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -138,7 +137,7 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -157,23 +156,24 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
 
     @property
     def transport(self) -> DocumentProcessorServiceTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
-            DocumentProcessorServiceTransport: The transport used by the client instance.
+            DocumentProcessorServiceTransport: The transport used by the client
+                instance.
         """
         return self._transport
 
     @staticmethod
     def human_review_config_path(project: str, location: str, processor: str,) -> str:
-        """Return a fully-qualified human_review_config string."""
+        """Returns a fully-qualified human_review_config string."""
         return "projects/{project}/locations/{location}/processors/{processor}/humanReviewConfig".format(
             project=project, location=location, processor=processor,
         )
 
     @staticmethod
     def parse_human_review_config_path(path: str) -> Dict[str, str]:
-        """Parse a human_review_config path into its component segments."""
+        """Parses a human_review_config path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/processors/(?P<processor>.+?)/humanReviewConfig$",
             path,
@@ -182,14 +182,14 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
 
     @staticmethod
     def processor_path(project: str, location: str, processor: str,) -> str:
-        """Return a fully-qualified processor string."""
+        """Returns a fully-qualified processor string."""
         return "projects/{project}/locations/{location}/processors/{processor}".format(
             project=project, location=location, processor=processor,
         )
 
     @staticmethod
     def parse_processor_path(path: str) -> Dict[str, str]:
-        """Parse a processor path into its component segments."""
+        """Parses a processor path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/processors/(?P<processor>.+?)$",
             path,
@@ -198,7 +198,7 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
 
     @staticmethod
     def common_billing_account_path(billing_account: str,) -> str:
-        """Return a fully-qualified billing_account string."""
+        """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
         )
@@ -211,7 +211,7 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
 
     @staticmethod
     def common_folder_path(folder: str,) -> str:
-        """Return a fully-qualified folder string."""
+        """Returns a fully-qualified folder string."""
         return "folders/{folder}".format(folder=folder,)
 
     @staticmethod
@@ -222,7 +222,7 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
 
     @staticmethod
     def common_organization_path(organization: str,) -> str:
-        """Return a fully-qualified organization string."""
+        """Returns a fully-qualified organization string."""
         return "organizations/{organization}".format(organization=organization,)
 
     @staticmethod
@@ -233,7 +233,7 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
 
     @staticmethod
     def common_project_path(project: str,) -> str:
-        """Return a fully-qualified project string."""
+        """Returns a fully-qualified project string."""
         return "projects/{project}".format(project=project,)
 
     @staticmethod
@@ -244,7 +244,7 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
 
     @staticmethod
     def common_location_path(project: str, location: str,) -> str:
-        """Return a fully-qualified location string."""
+        """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
             project=project, location=location,
         )
@@ -258,12 +258,12 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, DocumentProcessorServiceTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the document processor service client.
+        """Instantiates the document processor service client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -318,9 +318,10 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
                 client_cert_source_func = client_options.client_cert_source
             else:
                 is_mtls = mtls.has_default_client_cert_source()
-                client_cert_source_func = (
-                    mtls.default_client_cert_source() if is_mtls else None
-                )
+                if is_mtls:
+                    client_cert_source_func = mtls.default_client_cert_source()
+                else:
+                    client_cert_source_func = None
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -332,12 +333,14 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
             elif use_mtls_env == "always":
                 api_endpoint = self.DEFAULT_MTLS_ENDPOINT
             elif use_mtls_env == "auto":
-                api_endpoint = (
-                    self.DEFAULT_MTLS_ENDPOINT if is_mtls else self.DEFAULT_ENDPOINT
-                )
+                if is_mtls:
+                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
+                else:
+                    api_endpoint = self.DEFAULT_ENDPOINT
             else:
                 raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted values: never, auto, always"
+                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
+                    "values: never, auto, always"
                 )
 
         # Save or instantiate the transport.
@@ -352,8 +355,8 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
                 )
             if client_options.scopes:
                 raise ValueError(
-                    "When providing a transport instance, "
-                    "provide its scopes directly."
+                    "When providing a transport instance, provide its scopes "
+                    "directly."
                 )
             self._transport = transport
         else:
@@ -390,7 +393,6 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -419,10 +421,8 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         # there are no flattened fields.
         if not isinstance(request, document_processor_service.ProcessRequest):
             request = document_processor_service.ProcessRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -465,7 +465,6 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -497,10 +496,8 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         # there are no flattened fields.
         if not isinstance(request, document_processor_service.BatchProcessRequest):
             request = document_processor_service.BatchProcessRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -552,7 +549,6 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
                 This corresponds to the ``human_review_config`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -584,10 +580,8 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         # there are no flattened fields.
         if not isinstance(request, document_processor_service.ReviewDocumentRequest):
             request = document_processor_service.ReviewDocumentRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if human_review_config is not None:
                 request.human_review_config = human_review_config
 
