@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,22 +13,20 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
-from typing import Callable, Dict, Optional, Sequence, Tuple
+from typing import Callable, Dict, Optional, Sequence, Tuple, Union
 
 from google.api_core import grpc_helpers  # type: ignore
 from google.api_core import operations_v1  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+import google.auth  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.cloud.documentai_v1beta3.types import document_processor_service
-from google.longrunning import operations_pb2 as operations  # type: ignore
-
+from google.longrunning import operations_pb2  # type: ignore
 from .base import DocumentProcessorServiceTransport, DEFAULT_CLIENT_INFO
 
 
@@ -55,8 +52,8 @@ class DocumentProcessorServiceGrpcTransport(DocumentProcessorServiceTransport):
     def __init__(
         self,
         *,
-        host: str = "us-documentai.googleapis.com",
-        credentials: credentials.Credentials = None,
+        host: str = "documentai.googleapis.com",
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         channel: grpc.Channel = None,
@@ -70,7 +67,8 @@ class DocumentProcessorServiceGrpcTransport(DocumentProcessorServiceTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -180,8 +178,8 @@ class DocumentProcessorServiceGrpcTransport(DocumentProcessorServiceTransport):
     @classmethod
     def create_channel(
         cls,
-        host: str = "us-documentai.googleapis.com",
-        credentials: credentials.Credentials = None,
+        host: str = "documentai.googleapis.com",
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -212,13 +210,15 @@ class DocumentProcessorServiceGrpcTransport(DocumentProcessorServiceTransport):
             google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
               and ``credentials_file`` are passed.
         """
-        scopes = scopes or cls.AUTH_SCOPES
+
+        self_signed_jwt_kwargs = cls._get_self_signed_jwt_kwargs(host, scopes)
+
         return grpc_helpers.create_channel(
             host,
             credentials=credentials,
             credentials_file=credentials_file,
-            scopes=scopes,
             quota_project_id=quota_project_id,
+            **self_signed_jwt_kwargs,
             **kwargs,
         )
 
@@ -275,7 +275,7 @@ class DocumentProcessorServiceGrpcTransport(DocumentProcessorServiceTransport):
     def batch_process_documents(
         self,
     ) -> Callable[
-        [document_processor_service.BatchProcessRequest], operations.Operation
+        [document_processor_service.BatchProcessRequest], operations_pb2.Operation
     ]:
         r"""Return a callable for the batch process documents method over gRPC.
 
@@ -296,7 +296,7 @@ class DocumentProcessorServiceGrpcTransport(DocumentProcessorServiceTransport):
             self._stubs["batch_process_documents"] = self.grpc_channel.unary_unary(
                 "/google.cloud.documentai.v1beta3.DocumentProcessorService/BatchProcessDocuments",
                 request_serializer=document_processor_service.BatchProcessRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["batch_process_documents"]
 
@@ -304,7 +304,7 @@ class DocumentProcessorServiceGrpcTransport(DocumentProcessorServiceTransport):
     def review_document(
         self,
     ) -> Callable[
-        [document_processor_service.ReviewDocumentRequest], operations.Operation
+        [document_processor_service.ReviewDocumentRequest], operations_pb2.Operation
     ]:
         r"""Return a callable for the review document method over gRPC.
 
@@ -325,7 +325,7 @@ class DocumentProcessorServiceGrpcTransport(DocumentProcessorServiceTransport):
             self._stubs["review_document"] = self.grpc_channel.unary_unary(
                 "/google.cloud.documentai.v1beta3.DocumentProcessorService/ReviewDocument",
                 request_serializer=document_processor_service.ReviewDocumentRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["review_document"]
 
