@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,14 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
 from google.cloud.documentai_v1beta3.types import document as gcd_document
 from google.cloud.documentai_v1beta3.types import document_io
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-from google.rpc import status_pb2 as gr_status  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
+from google.rpc import status_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
@@ -43,7 +40,6 @@ __protobuf__ = proto.module(
 
 class ProcessRequest(proto.Message):
     r"""Request message for the process document method.
-
     Attributes:
         inline_document (google.cloud.documentai_v1beta3.types.Document):
             An inline document proto.
@@ -62,21 +58,16 @@ class ProcessRequest(proto.Message):
     inline_document = proto.Field(
         proto.MESSAGE, number=4, oneof="source", message=gcd_document.Document,
     )
-
     raw_document = proto.Field(
         proto.MESSAGE, number=5, oneof="source", message=document_io.RawDocument,
     )
-
-    name = proto.Field(proto.STRING, number=1)
-
+    name = proto.Field(proto.STRING, number=1,)
     document = proto.Field(proto.MESSAGE, number=2, message=gcd_document.Document,)
-
-    skip_human_review = proto.Field(proto.BOOL, number=3)
+    skip_human_review = proto.Field(proto.BOOL, number=3,)
 
 
 class HumanReviewStatus(proto.Message):
     r"""The status of human review on a processed document.
-
     Attributes:
         state (google.cloud.documentai_v1beta3.types.HumanReviewStatus.State):
             The state of human review on the processing
@@ -101,15 +92,12 @@ class HumanReviewStatus(proto.Message):
         ERROR = 4
 
     state = proto.Field(proto.ENUM, number=1, enum=State,)
-
-    state_message = proto.Field(proto.STRING, number=2)
-
-    human_review_operation = proto.Field(proto.STRING, number=3)
+    state_message = proto.Field(proto.STRING, number=2,)
+    human_review_operation = proto.Field(proto.STRING, number=3,)
 
 
 class ProcessResponse(proto.Message):
     r"""Response message for the process document method.
-
     Attributes:
         document (google.cloud.documentai_v1beta3.types.Document):
             The document payload, will populate fields
@@ -127,9 +115,7 @@ class ProcessResponse(proto.Message):
     """
 
     document = proto.Field(proto.MESSAGE, number=1, message=gcd_document.Document,)
-
-    human_review_operation = proto.Field(proto.STRING, number=2)
-
+    human_review_operation = proto.Field(proto.STRING, number=2,)
     human_review_status = proto.Field(
         proto.MESSAGE, number=3, message="HumanReviewStatus",
     )
@@ -137,7 +123,6 @@ class ProcessResponse(proto.Message):
 
 class BatchProcessRequest(proto.Message):
     r"""Request message for batch process document method.
-
     Attributes:
         name (str):
             Required. The processor resource name.
@@ -157,7 +142,6 @@ class BatchProcessRequest(proto.Message):
 
     class BatchInputConfig(proto.Message):
         r"""The message for input config in batch process.
-
         Attributes:
             gcs_source (str):
                 The Cloud Storage location as the source of
@@ -169,47 +153,39 @@ class BatchProcessRequest(proto.Message):
                 should be application/json.
         """
 
-        gcs_source = proto.Field(proto.STRING, number=1)
-
-        mime_type = proto.Field(proto.STRING, number=2)
+        gcs_source = proto.Field(proto.STRING, number=1,)
+        mime_type = proto.Field(proto.STRING, number=2,)
 
     class BatchOutputConfig(proto.Message):
         r"""The message for output config in batch process.
-
         Attributes:
             gcs_destination (str):
                 The output Cloud Storage directory to put the
                 processed documents.
         """
 
-        gcs_destination = proto.Field(proto.STRING, number=1)
-
-    name = proto.Field(proto.STRING, number=1)
+        gcs_destination = proto.Field(proto.STRING, number=1,)
 
+    name = proto.Field(proto.STRING, number=1,)
     input_configs = proto.RepeatedField(
         proto.MESSAGE, number=2, message=BatchInputConfig,
     )
-
     output_config = proto.Field(proto.MESSAGE, number=3, message=BatchOutputConfig,)
-
     input_documents = proto.Field(
         proto.MESSAGE, number=5, message=document_io.BatchDocumentsInputConfig,
     )
-
     document_output_config = proto.Field(
         proto.MESSAGE, number=6, message=document_io.DocumentOutputConfig,
     )
-
-    skip_human_review = proto.Field(proto.BOOL, number=4)
+    skip_human_review = proto.Field(proto.BOOL, number=4,)
 
 
 class BatchProcessResponse(proto.Message):
-    r"""Response message for batch process document method."""
+    r"""Response message for batch process document method.    """
 
 
 class BatchProcessMetadata(proto.Message):
     r"""The long running operation metadata for batch process method.
-
     Attributes:
         state (google.cloud.documentai_v1beta3.types.BatchProcessMetadata.State):
             The state of the current batch processing.
@@ -265,26 +241,18 @@ class BatchProcessMetadata(proto.Message):
                 document.
         """
 
-        input_gcs_source = proto.Field(proto.STRING, number=1)
-
-        status = proto.Field(proto.MESSAGE, number=2, message=gr_status.Status,)
-
-        output_gcs_destination = proto.Field(proto.STRING, number=3)
-
-        human_review_operation = proto.Field(proto.STRING, number=4)
-
+        input_gcs_source = proto.Field(proto.STRING, number=1,)
+        status = proto.Field(proto.MESSAGE, number=2, message=status_pb2.Status,)
+        output_gcs_destination = proto.Field(proto.STRING, number=3,)
+        human_review_operation = proto.Field(proto.STRING, number=4,)
         human_review_status = proto.Field(
             proto.MESSAGE, number=5, message="HumanReviewStatus",
         )
 
     state = proto.Field(proto.ENUM, number=1, enum=State,)
-
-    state_message = proto.Field(proto.STRING, number=2)
-
-    create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp.Timestamp,)
-
-    update_time = proto.Field(proto.MESSAGE, number=4, message=timestamp.Timestamp,)
-
+    state_message = proto.Field(proto.STRING, number=2,)
+    create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
+    update_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
     individual_process_statuses = proto.RepeatedField(
         proto.MESSAGE, number=5, message=IndividualProcessStatus,
     )
@@ -292,7 +260,6 @@ class BatchProcessMetadata(proto.Message):
 
 class ReviewDocumentRequest(proto.Message):
     r"""Request message for review document method.
-
     Attributes:
         inline_document (google.cloud.documentai_v1beta3.types.Document):
             An inline document proto.
@@ -307,22 +274,19 @@ class ReviewDocumentRequest(proto.Message):
     inline_document = proto.Field(
         proto.MESSAGE, number=4, oneof="source", message=gcd_document.Document,
     )
-
-    human_review_config = proto.Field(proto.STRING, number=1)
-
+    human_review_config = proto.Field(proto.STRING, number=1,)
     document = proto.Field(proto.MESSAGE, number=2, message=gcd_document.Document,)
 
 
 class ReviewDocumentResponse(proto.Message):
     r"""Response message for review document method.
-
     Attributes:
         gcs_destination (str):
             The Cloud Storage uri for the human reviewed
             document.
     """
 
-    gcs_destination = proto.Field(proto.STRING, number=1)
+    gcs_destination = proto.Field(proto.STRING, number=1,)
 
 
 class ReviewDocumentOperationMetadata(proto.Message):
@@ -355,13 +319,9 @@ class ReviewDocumentOperationMetadata(proto.Message):
         CANCELLED = 5
 
     state = proto.Field(proto.ENUM, number=1, enum=State,)
-
-    state_message = proto.Field(proto.STRING, number=2)
-
-    create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp.Timestamp,)
-
-    update_time = proto.Field(proto.MESSAGE, number=4, message=timestamp.Timestamp,)
-
+    state_message = proto.Field(proto.STRING, number=2,)
+    create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
+    update_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
     common_metadata = proto.Field(
         proto.MESSAGE, number=5, message="CommonOperationMetadata",
     )
@@ -369,7 +329,6 @@ class ReviewDocumentOperationMetadata(proto.Message):
 
 class CommonOperationMetadata(proto.Message):
     r"""The common metadata for long running operations.
-
     Attributes:
         state (google.cloud.documentai_v1beta3.types.CommonOperationMetadata.State):
             The state of the operation.
@@ -392,12 +351,9 @@ class CommonOperationMetadata(proto.Message):
         CANCELLED = 5
 
     state = proto.Field(proto.ENUM, number=1, enum=State,)
-
-    state_message = proto.Field(proto.STRING, number=2)
-
-    create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp.Timestamp,)
-
-    update_time = proto.Field(proto.MESSAGE, number=4, message=timestamp.Timestamp,)
+    state_message = proto.Field(proto.STRING, number=2,)
+    create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
+    update_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
